%define major	6
%define libname	%mklibname concord %major
%define devname	%mklibname concord -d

Summary:	Command-line Logitech Harmony remote programmer
Name:		concordance
Version:	1.5
Release:	%mkrel 5
License:	GPLv3+
Group:          System/Kernel and hardware
URL:		https://www.phildev.net/concordance/
Source:		https://github.com/jaymzh/concordance/releases/download/v%{version}/%{name}-%{version}.tar.bz2
BuildRequires:	pkgconfig(hidapi-libusb)
BuildRequires:	pkgconfig(libzip)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	python3-devel
BuildRequires:	perl-devel
BuildRequires:	swig

%description
This command-line software allows you to program your Logitech Harmony
remote using a configuration object retrieved from the Harmony website.

%package -n libconcord-common
Summary:	Common files of libconcord
Group:		System/Libraries

%description -n libconcord-common
Common files required by Logitech Harmony remote programmer library.

%package -n %{libname}
Summary:	System library of libconcord
Group:		System/Libraries
Requires:	libconcord-common >= %{version}-%{release}

%description -n %{libname}
Logitech Harmony remote programmer library for applications that use it.

%package -n %{devname}
Summary:	Development headers for libconcord
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	concord-devel = %{version}-%{release}

%description -n %{devname}
Development headers for developing applications that use libconcord, a
Logitech Harmony remote programmer library.

%package -n perl-concord
Summary:	Perl bindings for libconcord
Group:		Development/Perl
Requires:	%{libname} = %{version}-%{release}

%description -n perl-concord
Perl bindings for libconcord, a Logitech Harmony remote programmer
library.

%package -n python3-libconcord
Summary:	Python 3 bindings for libconcord
Group:		Development/Python
Requires:	%{libname} = %{version}-%{release}

%description -n python3-libconcord
Python 3 bindings for libconcord, a Logitech Harmony remote programmer
library.

%prep
%autosetup -p1

%build
pushd libconcord
  # patch0
  autoreconf -fi
  %configure --disable-static --disable-mime-update
  %make_build
  %make_build udev
popd

pushd libconcord/bindings/perl
  swig -perl5 concord.i
  %{__perl} Makefile.PL INSTALLDIRS=vendor INC=-I../..
  %make_build OTHERLDFLAGS="-L../../.libs" LDLOADLIBS="-lconcord"
popd

pushd concordance
  %configure CPPFLAGS=-I../libconcord LDFLAGS="%{?ldflags} -L../libconcord/.libs"
  %make_build
popd

pushd consnoop
  %make_build CXXFLAGS="%{optflags} %{?ldflags}"
popd

pushd libconcord/bindings/python
  2to3-%{python3_version} -w libconcord.py
  %pyproject_wheel
popd

%install
%make_install -C libconcord \
	install_udev UDEVROOT=%{_prefix}
#
%make_install -C libconcord/bindings/perl
%make_install -C concordance

pushd libconcord/bindings/python
  %pyproject_install
  %pyproject_save_files libconcord
popd

# useful or not? include for now:
install -m755 consnoop/consnoop %{buildroot}%{_bindir}

# fix debug info extraction
chmod u+w %{buildroot}%{perl_vendorarch}/auto/concord/concord.so

%post -n libconcord-common
# apply new/updated rules
/sbin/udevadm trigger --subsystem-match=usb --attr-match=idVendor=046d --attr-match=idProduct="c1*"
/sbin/udevadm trigger --subsystem-match=usb --attr-match=idVendor=0400 --attr-match=idProduct="c359"

%files
%doc README.md
%doc Changelog
%{_bindir}/concordance
%{_mandir}/man1/concordance.1*

%files -n libconcord-common
%{_udevrulesdir}/80-libconcord-usbnet.rules
%{_udevrulesdir}/60-libconcord.rules
%{_prefix}/lib/udev/start_concordance_dhcpd.sh
%{_prefix}/lib/udev/start_concordance_dhcpd_wrapper.sh
%{_datadir}/mime/packages/libconcord.xml

%files -n %{libname}
%{_libdir}/libconcord.so.%{major}{,.*}

%files -n %{devname}
%doc libconcord/README
%{_bindir}/consnoop
%{_libdir}/libconcord.so
%{_includedir}/libconcord.h

%files -n perl-concord
%{perl_vendorarch}/concord.pm
%{perl_vendorarch}/auto/concord/

%files -n python3-libconcord -f %{pyproject_files}


%changelog
* Fri Dec 27 2024 daviddavid <daviddavid> 1.5-5.mga10
+ Revision: 2130660
- fix debug info extraction by fixing properly file permissions

* Fri Dec 27 2024 daviddavid <daviddavid> 1.5-4.mga10
+ Revision: 2130649
- fix debug info extraction by fixing file permissions

* Fri Aug 23 2024 tv <tv> 1.5-3.mga10
+ Revision: 2089662
- Rebuild for perl-5.40

* Wed Dec 27 2023 papoteur <papoteur> 1.5-2.mga10
+ Revision: 2022303
- rebuild for python 3.12
- adapt to pyproject

* Fri Sep 16 2022 papoteur <papoteur> 1.5-1.mga9
+ Revision: 1889197
- new 1.5

* Mon Jun 06 2022 umeabot <umeabot> 1.4-8.mga9
+ Revision: 1861485
- Rebuild for Perl 5.36

* Sat Mar 26 2022 umeabot <umeabot> 1.4-7.mga9
+ Revision: 1827853
- Mageia 9 Mass Rebuild

* Wed Mar 02 2022 mrambo3501 <mrambo3501> 1.4-6.mga9
+ Revision: 1787554
- rebuild for python-3.10

* Mon May 24 2021 umeabot <umeabot> 1.4-5.mga9
+ Revision: 1726356
- Rebuild for perl 5.34

* Fri Mar 26 2021 daviddavid <daviddavid> 1.4-4.mga9
+ Revision: 1710449
- rebuild for python 3.9

* Wed Jun 17 2020 umeabot <umeabot> 1.4-3.mga8
+ Revision: 1594205
- Rebuild for perl 5.32

* Mon Feb 17 2020 umeabot <umeabot> 1.4-2.mga8
+ Revision: 1537791
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Nov 11 2019 daviddavid <daviddavid> 1.4-1.mga8
+ Revision: 1459139
- new version: 1.4
- now libmajor is 5

* Mon Oct 14 2019 daviddavid <daviddavid> 1.3-1.mga8
+ Revision: 1453199
- new version: 1.3

* Tue Sep 17 2019 tv <tv> 1.2-3.mga8
+ Revision: 1442909
- rebuild for python-3.8

* Sat Aug 31 2019 wally <wally> 1.2-2.mga8
+ Revision: 1435910
- make perl and python3 pkgs to requires lib pkg

* Sat Aug 31 2019 wally <wally> 1.2-1.mga8
+ Revision: 1435909
- new version 1.2
- new libmajor 4
- switch to python3

* Tue Aug 27 2019 tmb <tmb> 1.0-19.mga8
+ Revision: 1433410
- rebuild for perl 5.30

* Sun Sep 23 2018 umeabot <umeabot> 1.0-18.mga7
+ Revision: 1296764
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 pterjan <pterjan> 1.0-17.mga7
+ Revision: 1248923
- Rebuild for perl 5.28

* Thu Aug 31 2017 pterjan <pterjan> 1.0-16.mga7
+ Revision: 1150249
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 1.0-15.mga7
+ Revision: 1126683
- Rebuild against new Perl 5.26

* Sat Jun 18 2016 pterjan <pterjan> 1.0-14.mga6
+ Revision: 1022106
- Rebuild for perl 5.22.2

* Sun Feb 14 2016 umeabot <umeabot> 1.0-13.mga6
+ Revision: 959813
- Mageia 6 Mass Rebuild

* Sat Oct 24 2015 daviddavid <daviddavid> 1.0-12.mga6
+ Revision: 894878
- use new python macros to fix build

* Fri Jun 26 2015 sander85 <sander85> 1.0-11.mga6
+ Revision: 844000
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 1.0-10.mga5
+ Revision: 742050
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.0-9.mga5
+ Revision: 726061
- rebuild for missing pythoneggs deps

* Thu Sep 18 2014 umeabot <umeabot> 1.0-8.mga5
+ Revision: 693668
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.0-7.mga5
+ Revision: 678518
- Mageia 5 Mass Rebuild

* Sat Jul 05 2014 pterjan <pterjan> 1.0-6.mga5
+ Revision: 643568
- Replace libusb*-devel BuildRequires by better ones

* Tue Jun 03 2014 pterjan <pterjan> 1.0-5.mga5
+ Revision: 630766
- Rebuild for perl 5.20

* Sat May 31 2014 pterjan <pterjan> 1.0-4.mga5
+ Revision: 628142
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.0-3.mga4
+ Revision: 542530
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 1.0-2.mga4
+ Revision: 497680
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Jul 31 2013 fwang <fwang> 1.0-1.mga4
+ Revision: 461462
- update file list
- bump libmajor
- update ldflags
- br  zzip
- rediff automake patch
- new version 1.0

* Wed Jul 31 2013 fwang <fwang> 0.24-6.mga4
+ Revision: 461423
- drop unneeded chrpath br
- specify ldloadlibs
- specify ldloadlibs
- set otherldflags
- update libs

* Wed Jul 31 2013 fwang <fwang> 0.24-5.mga4
+ Revision: 461413
- use pushd
- try fix build with recent automake

* Wed May 29 2013 fwang <fwang> 0.24-4.mga4
+ Revision: 430383
- rebuild for new perl

* Wed Jan 23 2013 fwang <fwang> 0.24-3.mga3
+ Revision: 391215
- use correct prefix
- update rpm group

* Fri Jan 11 2013 umeabot <umeabot> 0.24-2.mga3
+ Revision: 348111
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 07 2012 fwang <fwang> 0.24-1.mga3
+ Revision: 315682
- try to fix build with latest am
- new verison 0.24
- rebuild for new perl
+ jquelin <jquelin>
- perl 5.16 rebuild

* Sat Jun 11 2011 stormi <stormi> 0.23-6.mga2
+ Revision: 103790
- fix typo in description

* Sat Jun 11 2011 sander85 <sander85> 0.23-5.mga2
+ Revision: 103746
- perl 5.14

* Wed Jan 19 2011 jquelin <jquelin> 0.23-4.mga1
+ Revision: 23863
- perl 5.12 rebuild
- rebuild
- rebuild

* Tue Jan 18 2011 pterjan <pterjan> 0.23-3.mga1
+ Revision: 21817
- Rebuild for python 2.7

* Sun Jan 16 2011 anssi <anssi> 0.23-2.mga1
+ Revision: 20094
- guard mdkversion uses with %%distribution check
- imported package concordance


* Sun Nov 21 2010 Funda Wang <fwang@mandriva.org> 0.23-2mdv2011.0
+ Revision: 599412
- rebuild for py2.7

* Sat Sep 04 2010 Anssi Hannula <anssi@mandriva.org> 0.23-1mdv2011.0
+ Revision: 575831
- new version
- new major
- enable adaptation for cooker udev

* Wed Aug 04 2010 Funda Wang <fwang@mandriva.org> 0.22-1mdv2011.0
+ Revision: 565781
- New version 0.22

* Tue Jul 20 2010 Jérôme Quelin <jquelin@mandriva.org> 0.21-3mdv2011.0
+ Revision: 555705
- rebuild

* Wed Jun 23 2010 Anssi Hannula <anssi@mandriva.org> 0.21-2mdv2010.1
+ Revision: 548753
- add udev rules to apply ACL to the Harmony remotes (udev-acl.patch)
- clean the udev exception rules a bit (clean-udev-rules.patch)
- move mime types to the new subpackage libconcord-common
- add release to devel provides

* Sun Jul 12 2009 Anssi Hannula <anssi@mandriva.org> 0.21-1mdv2010.1
+ Revision: 395311
- add missing include (includes.patch, fixes build with current
  toolchain)
- new version
- new major
- add mime type files (mime.patch based on patch from Adam Williamson,
  replacing the used mimetype with the ones reported by logitech server)

* Sat Jan 03 2009 Funda Wang <fwang@mandriva.org> 0.20-1.20081101.2mdv2009.1
+ Revision: 323756
- rebuild

* Sun Nov 02 2008 Anssi Hannula <anssi@mandriva.org> 0.20-1.20081101.1mdv2009.1
+ Revision: 299196
- initial Mandriva release

